#
# spec file for package deepin-dock
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2022 Hillwood Yang <hillwood@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name dde-dock

Name:           deepin-dock
Version:        5.5.65
Release:        1.9
Summary:        Deepin dock
License:        LGPL-3.0-or-later
Group:          System/GUI/Other
URL:            https://github.com/linuxdeepin/dde-dock
Source0:        https://github.com/linuxdeepin/dde-dock/archive/%{version}/%{_name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  dtkcommon >= 5.5.20
BuildRequires:  dtkcore >= 5.0.0
BuildRequires:  gmock
BuildRequires:  gtest
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-qtbase-private-headers-devel
BuildRequires:  libqt5-qtdeclarative-devel
BuildRequires:  libqt5-qttools-devel
BuildRequires:  cmake(DdeControlCenter)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(dbusmenu-qt5)
BuildRequires:  pkgconfig(dde-network-utils)
BuildRequires:  pkgconfig(dframeworkdbus) >= 2.0
BuildRequires:  pkgconfig(dtkwidget) >= 5.0.0
BuildRequires:  pkgconfig(gsettings-qt)
BuildRequires:  pkgconfig(libdeepin_pw_check)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb-composite)
BuildRequires:  pkgconfig(xcb-ewmh)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-image)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xtst)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
deepin desktop-environment - dock module

%package devel
Summary:        Development tools for deepin dock
Group:          Development/Libraries/C and C++

%description devel
The deepin-dock-devel package contains the header files for deepin-dock.

%lang_package

%prep
%autosetup -p1 -n %{_name}-%{version}
sed -i "s/lrelease/lrelease-qt5/g" translate_generation.sh
sed -i 's|no</allow_any>|auth_admin</allow_any>|g' plugins/overlay-warning/com.deepin.dde.dock.overlay.policy
# sed -i 's|lib/|${CMAKE_INSTALL_LIBDIR}/|g' plugins/*/CMakeLists.txt
# sed -i 's|/usr/lib|@CMAKE_INSTALL_LIBDIR@|g' frame/controller/dockpluginscontroller.cpp \
# plugins/tray/system-trays/systemtrayscontroller.cpp

sed -i '/TARGETS/s|lib|%{_lib}|' plugins/*/CMakeLists.txt \
                                 plugins/plugin-guide/plugins-developer-guide.md

sed -i 's|/usr/lib|%{_libdir}|' frame/controller/dockpluginscontroller.cpp \
                          frame/window/mainpanelcontrol.cpp \
                          plugins/tray/system-trays/systemtrayscontroller.cpp

sed -i 's|libdir.*|libdir=%{_libdir}|' dde-dock.pc.in

sed -i 's|/usr/lib/dde-dock/plugins|%{_libdir}/dde-dock/plugins|' plugins/plugin-guide/plugins-developer-guide.md
sed -i 's|local/lib/dde-dock/plugins|local/%{_lib}/dde-dock/plugins|' plugins/plugin-guide/plugins-developer-guide.md

%build
%cmake
%cmake_build

%install
%cmake_install

rm -rf %{buildroot}%{_datadir}/polkit-1

%files
%doc README.md CHANGELOG.md
%license LICENSE
%{_bindir}/%{_name}
%{_libdir}/%{_name}
%{_datadir}/%{_name}
%{_datadir}/glib-2.0/schemas/com.deepin.dde.dock.module.gschema.xml
%dir %{_sysconfdir}/dde-dock
%dir %{_sysconfdir}/dde-dock/indicator
%config %{_sysconfdir}/dde-dock/indicator/keybord_layout.json
%dir %{_datadir}/dsg
%dir %{_datadir}/dsg/configs
%dir %{_datadir}/dsg/configs/org.deepin.dde.control-center
%dir %{_datadir}/dsg/configs/org.deepin.dde.dock
%{_datadir}/dsg/configs/org.deepin.dde.control-center/*.json
%{_datadir}/dsg/configs/org.deepin.dde.dock/*.json
%dir %{_libdir}/dde-control-center
%dir %{_libdir}/dde-control-center/modules
%{_libdir}/dde-control-center/modules/libdcc-dock-plugin.so

%files devel
%{_includedir}/%{_name}
%dir %{_libdir}/cmake/DdeDock
%{_libdir}/cmake/DdeDock/DdeDockConfig.cmake
%{_libdir}/pkgconfig/%{_name}.pc

%files lang
%{_datadir}/dcc-dock-plugin

%changelog
* Wed Aug 24 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.65
  * Always show airplane mode
  * Add sort format for date
  * Fix bugs
* Tue Jun 28 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.51
  * Fix bugs
  * Optimize wayland support
* Tue Apr  5 2022 Hillwood Yang <<hillwood@opensuse.org>
- Update version to 5.5.12
  * Optimize launch time
  * Fix bugs
- Drop deepin-dock-link-libraries.patch, merged by upstream
* Wed Feb 23 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.5.9
  * Add control center plugin
  * Update translations
  * Fix bug
* Thu Dec 16 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.69
  * Change copyright to LGPLv3
  * Fix bugs
* Sat Oct 23 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.52
  * Fix bugs
* Mon Sep 20 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.39
  * Add api for configuring keybord layout
  * Update translations
  * Fix bugs
* Sun Jul 25 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.28
  * New feature: scan wifi on pannel
  * Optimize code
  * Fix bugs
* Sun Jun 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Remove the unneeded QtWebKit build dependency.
* Sat May  1 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.7
  * Update com.deepin.daemon.Timedate API
  * Add Mock
  * Fix bugs
* Tue Mar 16 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.4.4
  * Add important filelist
  * Fix font size for clock plugin
  * Fix bugs
  * Optimize code structure
* Mon Feb 22 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.3.64
  * The fresh ui
  * fix bugs
* Tue Apr 28 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.1.0.1
  * Fix bugs
  * Add features
- Link libraries to fix build, add deepin-dock-link-libraries.patch
* Sun Jul 14 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 4.10.7
  * Fix overlay: head define conflict
  * disable show animation for sw mips and arm
  * plugin init is done in other threads
  * remove load plugins timer
  * docs: Add documents for paths of local plugins
  * tray: disable tray for local config
  * plugin: support init plugins for ~/.local/lib/dde-dock/plugins
  * disable show animation for sw platform
  * Fix 2d: Clicking on the preview will crash
  * power: use onBattery to replace batteryState to check is used battery
  * Fix overlay: disable overlay failed
  * Fix plugins: scrolling on the item, popup will hide
  * Fix preview: cannot switch preview window
  * tray: cannot click indicator
  * Fix typos
  * network: refresh loading icon not align center
  * overlay: polkit dialog not translation message
  * preview: float preview background have wrong offset, crash when click active
    item on 2d
  * tray:indicator click is invalid, Adding a keyboard layout for the first time
    will crash
  * Fix network: refresh loading icon not align center
  * Fix quick click on the preview window will crash
  * Fix translation of polkit message of overlayroot-disable in stable system
  * Fix no notify be sent when plugin's qt version is incompatible
* Wed Apr 17 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 4.9.7
  * Fix can not hover preview after drag
  * Fix preview window can not be raised after clicked preview snapshot
  * Fix plugin settings value can not transform to Json value in qt 5.7
  * Fix not send plugin incompatible notify
  * Fix plugin settings lost after save to daemon dbus
  * Fix duplicate wired item tray
  * Update dock plugin version
  * refresh sort order and container after DeepinSync
  * update all plugins to support take effect in time for Deepin-Sync
  * update plugin interface version
  * access plugin settings from dock dbus daemon
  * Fix dock position and size is wrong on multiple screens and the screens have
    different device scale ratio
  * Fix arm: disable power module
  * Fix exec pkexec failed cause the Polkit dbus is not startup when just login
  * Fix cmdline read failed
  * Fix not detect hotspot enabled
  * Fix close button alignment in 2D mode
  * Fix pixmap be clipped
  * Fix hovering preview picture size adjust
  * add overlay warning plugin
  * enable CMAKE_EXPORT_COMPILE_COMMANDS by default
  * add cancel animation for drag to undock operation
  * Fix indicator not display
  * added multiple indicator tray of one indicator provider
  * Fix activating indicator not show when activate a wireless from other place
  * keyboard layout indicator support context menu
  * send a notify when plugin is not compatible
  * trash plugin enable be disable
  * Fix wireless item display problem when ssid contains "&"
  * Fix fashion tray expand error after double click control widget
  * optimize plugin guide
  * Fix shutdown plugin support hibernate* place holder item not be removed
    after drag leave in touch screen
  * Fix tips widget size not change after system font size changed
  * Fix obtain opacity value too frequently when startup
  * Fix show dock menu when click on some area out of tray
  * Fix can not show mutiple tray of one application
  * Fix warning when get window property for xembed tray
  * animation of hold spliter
  * add hold container
  * add a container widget for hold on trays
  * update plugin API version  * Fix xembed tray click response
  * Fix build package
  * Fix dock crash and sni tray status property process
  * Fix can not drag back to normal container
* Wed Jan  9 2019 hillwood@opensuse.org
- Update version to 4.8.6
  * Fix bug
  * Update features
* Mon Mar 19 2018 hillwood@opensuse.org
- Update version to 4.6.1
  * use cmake instead of qmake5
  * update deepin-dock-link-some-libraries.patch
  * Bug Fixes
    + sound input sink volume slider not init
    + update trayWidget on fashion mode
    + hidpi support for indicatortraywidget
    + indicatortraywidget connect error pertoires slots
    + Adapt lintian
    + dock hide behavior error when popup menu
    + menu auto hide
    + positioned at wrong place
    + show control-center not work
    + container item icon not clearly
    + dont show container tips if it's empty
    + aliasing border on highlighting app icon
    + dock frontend rect not support hiDPI
    + sound slider use svg
    + network refresh button support hidpi
    + network refresh button not visiable when device on
  * Features:
    + add keybord_layout.json
    + add keyboard layout plugin
    + support indicator traywidget
    + open dde-calendar with dbus call
    + **keyboard_layout:**  add new dbus interface
    + network:
    + add refresh animation
    + support cloned address
    + **plugins:**  keep order
    + **system-tray:**  using native popup
* Fri Dec  1 2017 hillwood@opensuse.org
- Update to 4.5.7
  * Using system theme icon in network plugin
  * Fix dock position error in multi screen
  * Forbid using theme icon in network plugin.
  * Fix dock crash if system tray' app is quit.
  * Minor bug fixes.
  * Improve popup auto hide algorithm
  * Fix window size error when new item inserted.
  * Improve HiDPI issues.
  * Opmitize memory usage.
  * Improve user experience.
  * Memory issue fixes.
  * Network add connecting animation
  * Fix systemtray not align vertial center
  * Update translations
  * Fix power icon auto-hide not work perfectly
  * New plugin API.
  * HiDPI support.
* Mon Oct  2 2017 hillwood@opensuse.org
- Initial package.
- Add deepin-doc-link-some-libraries.patch
  * Fix the lost pkgconfig item.
